/* Main Button Area css
============================================================================================ */
.main_btn{
	display: inline-block;
	background: $primary-color;
	padding: 0px 32px;
	letter-spacing: 0.25px;
	color: #fff;
	font-family: $body-font;
	font-size: 12px;
	font-weight: 500;
	line-height: 44px;
	outline: none !important;
	box-shadow: none !important;
	text-align: center;
	border: 1px solid $primary-color;
	cursor: pointer;
	text-transform: uppercase;
	@include transition;
	border-radius: 5px;
	&:hover{
		background: transparent;
		color: $primary-color;
	}
}
.main_btn2{
	display: inline-block;
	background: $primary-color;
	padding: 0px 32px;
	color: #fff;
	font-family: $body-font;
	font-size: 13px;
	font-weight: 500;
	line-height: 38px;
	border-radius: 0px;
	outline: none !important;
	box-shadow: none !important;
	text-align: center;
	border: 1px solid $primary-color;
	cursor: pointer;
	@include transition;
	&:hover{
		background: transparent;
		color: $primary-color;
	}
}
.submit_btn{
	display: inline-block;
	background: $primary-color;
	padding: 0px 30px;
	color: #fff;
	font-family: $body-font;
	font-size: 14px;
	font-weight: 500;
	line-height: 38px;
	border: 1px solid $primary-color;
	border-radius: 0px;
	outline: none !important;
	box-shadow: none !important;
	text-align: center;
	border: 1px solid $primary-color;
	cursor: pointer;
	@include transition;
	&:hover{
		background: transparent;
		color: $primary-color;
	}
}

.white_bg_btn{
	display: inline-block;
	background: $offwhite;
	padding: 0px 35px;
	color: $title-color;
	font-family: $body-font;
	font-size: 13px;
	font-weight: 500;
	line-height: 34px;
	border-radius: 0px;
	outline: none !important;
	box-shadow: none !important;
	text-align: center;
	border: 1px solid #eeeeee;
	cursor: pointer;
	@include transition;
	&:hover{
		background: $primary-color;
		color: #fff;
		border-color: $primary-color;
	}
}
.org_btn{
	padding: 0px 40px;
    background-image: linear-gradient(to right, #f766a5 0%, #f78762 51%, #f766a5 100%);
    background-size: 200% auto;
    z-index: 2;
    display: inline-block;
    transition: all 400ms ease-out;
    text-align: center;
    color: #fff;
    font-size: 14px;
	font-weight: 600;
	text-transform: uppercase;
    font-family: $title-font;
    line-height: 50px;
    border-radius: 5px;
    &:hover{
        background-position: right center;
        color: #fff;
    }
}
.green_btn{
	padding: 0px 40px;
    background-image: linear-gradient(to right, #73ca96 0%, #98d370 51%, #73ca96 100%);
    background-size: 200% auto;
    z-index: 2;
    display: inline-block;
    transition: all 400ms ease-out;
    text-align: center;
    color: #fff;
    font-size: 14px;
	font-weight: 600;
	text-transform: uppercase;
    font-family: $title-font;
    line-height: 50px;
    border-radius: 5px;
    &:hover{
        background-position: right center;
        color: #fff;
    }
}
/* End Main Button Area css
============================================================================================ */